@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: mcblock.cc 12091 2022-11-29 05:05:27Z dwm $
+// @(#) $Id: mcblock.cc 12355 2024-05-04 03:27:39Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2015
 //  All rights reserved.
@@ -63,7 +63,7 @@ extern "C" {
 using namespace Dwm;
 using namespace std;
 
-static const Dwm::CvsTag cvstag("@(#) $Name$ $Id: mcblock.cc 12091 2022-11-29 05:05:27Z dwm $");
+static const Dwm::CvsTag cvstag("@(#) $Name$ $Id: mcblock.cc 12355 2024-05-04 03:27:39Z dwm $");
 
 //----------------------------------------------------------------------------
 //!  
@@ -909,12 +909,10 @@ static bool CoalesceEntries(const string & dbFilename)
   rc = db.Load(dbFilename);
 
   if (rc) {
-    //  Coalesce
-    if (db.Coalesce()) {
-      rc = db.Save(dbFilename);
-      if (! rc) {
-        cerr << "Failed to save to " << dbFilename << '\n';
-      }
+    db.Coalesce();
+    rc = db.Save(dbFilename);
+    if (! rc) {
+      cerr << "Failed to save to " << dbFilename << '\n';
     }
   }
   else {
