@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmMcBlockDb.cc 12351 2024-05-03 09:12:30Z dwm $
+// @(#) $Id: DwmMcBlockDb.cc 12356 2024-05-04 03:28:14Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2015
 //  All rights reserved.
@@ -48,7 +48,7 @@ extern "C" {
 
 #include "DwmMcBlockDb.hh"
 
-static const Dwm::CvsTag cvstag("@(#) $Name$ $Id: DwmMcBlockDb.cc 12351 2024-05-03 09:12:30Z dwm $");
+static const Dwm::CvsTag cvstag("@(#) $Name$ $Id: DwmMcBlockDb.cc 12356 2024-05-04 03:28:14Z dwm $");
 
 using namespace std;
 
@@ -103,22 +103,15 @@ namespace Dwm {
       return rc;
     }
 
-#if 0
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool Db::Coalesce()
+    void Db::Coalesce()
     {
-      bool  rc = false;
-      if (CombineAdjacents()) {
-        rc = true;
-      }
-      if (CombineCovered()) {
-        rc = true;
-      }
-      return rc;
+      CombineAdjacents();
+      CombineCovered();
+      return;
     }
-#endif
     
     //------------------------------------------------------------------------
     //!  
